@@ -4,16 +4,21 @@
 #' The methodology is inspired by the proposal of Cobo et al. (2011). 
 #' 
 #' \code{thematicMap} starts from a co-occurrence keyword network to plot in a 
-#' two-dimesional map the typological themes of a domain.
+#' two-dimesional map the typological themes of a domain.\cr\cr
+#' 
+#' Reference:\cr
+#' Cobo, M. J., Lopez-Herrera, A. G., Herrera-Viedma, E., & Herrera, F. (2011). An approach for detecting, quantifying, 
+#' and visualizing the evolution of a research field: A practical application to the fuzzy sets theory field. Journal of Informetrics, 5(1), 146-166.\cr
 #' 
 #' 
 #' @param M is a bibliographic dataframe.
 #' @param field is the textual attribute used to build up the thematic map. It can be \code{field = c("ID","DE", "TI", "AB")}.
 #' \code{\link{biblioNetwork}} or \code{\link{cocMatrix}}.
 #' @param n is an integer. It indicates the number of terms to include in the analysis.
-#' @param minfreq is a integer. It indicates the minimun frequency of a cluster.
-#' @param stemming is logical. If it is TRUE the word (from titles or abtracts) will be stemmed (using the Porter's algorithm).
-#' @param size is numerical. It indicates del size of the cluster circles and is a numebr in the range (0.01,1).
+#' @param minfreq is a integer. It indicates the minimum frequency of a cluster.
+#' @param stemming is logical. If it is TRUE the word (from titles or abstracts) will be stemmed (using the Porter's algorithm).
+#' @param size is numerical. It indicates del size of the cluster circles and is a number in the range (0.01,1).
+#' @param n.labels is integer. It indicates how many labels associate to each cluster. Default is \code{n.labels = 1}.
 #' @param repel is logical. If it is TRUE ggplot uses geom_label_repel instead of geom_label.
 #' @return a list containing:
 #' \tabular{lll}{
@@ -36,16 +41,16 @@
 #'
 #' @export
 
-thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.5, repel=TRUE){
+thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.5, n.labels=1, repel=TRUE){
   
   switch(field,
          ID={
            NetMatrix <- biblioNetwork(M, analysis = "co-occurrences", network = "keywords", sep = ";")
-           
+           TERMS=tolower(M$ID)
          },
          DE={
            NetMatrix <- biblioNetwork(M, analysis = "co-occurrences", network = "author_keywords", sep = ";")
-           
+           TERMS=tolower(M$DE)
          },
          TI={
            #if(!("TI_TM" %in% names(values$M))){values$M=termExtraction(values$M,Field="TI",verbose=FALSE, stemming = input$stemming)}
@@ -141,6 +146,16 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
   
   df$words=W[,2]
   
+  ### number of labels for each cluster
+  labels=gsub("\\d", "",df$words)
+  L=unlist(lapply(labels, function(l){
+    l=strsplit(l," \\\n")
+    l=paste(l[[1]][1:min(n.labels,lengths(l))], collapse="\n")
+  }))
+  df$name_full=L
+  ###
+  
+  
   meandens=mean(df$rdensity)
   meancentr=mean(df$rcentrality)
   #df=df[df$freq>=minfreq,]
@@ -155,8 +170,8 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
     geom_point(group="NA",aes(size=log(as.numeric(df$freq))),shape=20,col=adjustcolor(df$color,alpha.f=0.5))     # Use hollow circles
   
   if (isTRUE(repel)){
-  g=g+geom_label_repel(aes(group="NA",label=ifelse(df$freq>1,unlist(tolower(df$name)),'')),size=3*(1+size),angle=0)}else{
-    g=g+geom_text(aes(group="NA",label=ifelse(df$freq>1,unlist(tolower(df$name)),'')),size=3*(1+size),angle=0)
+  g=g+geom_label_repel(aes(group="NA",label=ifelse(df$freq>1,unlist(tolower(df$name_full)),'')),size=3*(1+size),angle=0)}else{
+    g=g+geom_text(aes(group="NA",label=ifelse(df$freq>1,unlist(tolower(df$name_full)),'')),size=3*(1+size),angle=0)
   }
   
     g=g+geom_hline(yintercept = meandens,linetype=2, color=adjustcolor("black",alpha.f=0.7)) +
@@ -177,6 +192,20 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
   words$Cluster=as.numeric(factor(words$Cluster))
   row.names(df)=NULL
 
-  results=list(map=g, clusters=df, words=words,nclust=dim(df)[1], net=Net)
+  ### Adding column Topics
+  M$TOPIC=""
+  
+  #View(res$words)
+  if (field %in% c("ID", "DE")) {
+    ID = paste(TERMS, ";", sep = "")
+    for (i in 1:nrow(words)) {
+      w = paste(words$Words[i], ";", sep = "")
+      TOPIC = paste(words$Cluster_Label[i], ";", sep = "")
+      ind = which(regexpr(w, ID) > -1)
+      M$TOPIC[ind] = paste(M$TOPIC[ind], TOPIC, sep = "")
+    }
+  } else {M$TOPIC="NA"}
+  
+  results=list(map=g, clusters=df, words=words,nclust=dim(df)[1], net=Net, TOPIC=M$TOPIC)
 return(results)
 }
\ No newline at end of file
